--[[-----------------------------------------------------------------------------
 Copyright (c) 2012 Sierra Wireless and others.
 All rights reserved. This program and the accompanying materials
 are made available under the terms of the Eclipse Public License v1.0
 which accompanies this distribution, and is available at
 http://www.eclipse.org/legal/epl-v10.html

 Contributors:
     Laurent Barthelemy for Sierra Wireless - initial API and implementation
     Fabien Fleutot     for Sierra Wireless - initial API and implementation
     Romain Perier      for Sierra Wireless - initial API and implementation
-----------------------------------------------------------------------------
]]

--[[-
 This module provides the ability to send and receive SMS (Short Message
 Service) messages via the embedded radio module.

 @module sms

]]

--[[------------------------------------------------------------------------------
 Initialize the module. No service provided by this module will work unless
 this initializer function has been called first.

 @function [parent=#sms] init
 @return a true value upon success
 @return `nil` followed by an error message otherwise.

]]

--[[------------------------------------------------------------------------------
 Sends an SMS.
 Multiple SMS sending is done automatically if the message cannot be held in one SMS.

 @function [parent=#sms] send
 @param recipient string, number/name of the SMS recipient.
 @param message string containing the message (binary).
 @param format string defining the format to use to send the message.
  Accepted values are "7bits", "8bits" or "ucs2", supported formats may differ depending on the hardware and network capabilities.
 @return `"ok"` on success.
 @return `nil` followed by an error message otherwise.

]]

--[[------------------------------------------------------------------------------
 Registers a callback on SMS reception.
 New SMS will be notified if the content (sender or message) of the SMS
 matches the given patterns.

 @function [parent=#sms] register
 @param callback function to be called on sms reception matching both patterns
  with recepient and message as parameters.
  Callback signature: `callback(recipient_string, message_string)`.
 @param senderp string [lua pattern](http://www.lua.org/pil/20.2.html)
  that matches the sender address; `nil` means "no filtering".
 @param messagep string [lua pattern](http://www.lua.org/pil/20.2.html)
  that matches the message (sms content), `nil` means "no filtering".
 @return id (can be any Lua non-nil value) should be used only to
  call @{#sms.unregister}.
 @return `nil` followed by an error message otherwise.

]]

--[[------------------------------------------------------------------------------
 Cancels a callback registration on SMS reception.

 @function [parent=#sms] unregister
 @param id returned by a previous @{#sms.register} call.
 @return `"ok"` on success.
 @return `nil` followed by an error message otherwise.

]]

return nil
